"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const antd_1 = require("antd");
const react_1 = __importDefault(require("react"));
const use_debounce_1 = require("use-debounce");
const errorHandler_1 = require("../utils/errorHandler");
const generateQueryString_1 = require("../utils/generateQueryString");
const pagination_1 = require("../utils/pagination");
const DEFAULT_LIMIT = 25;
function useFetchList(props) {
    const [isLoading, setIsLoading] = react_1.default.useState(false);
    const [data, setData] = react_1.default.useState([]);
    const [pagination, setPagination] = react_1.default.useState(Object.assign({}, pagination_1.INITIAL_PAGINATION));
    const [query, setQuery] = react_1.default.useState(Object.assign(Object.assign(Object.assign({}, pagination_1.INITIAL_QUERY), { limit: props.limit || DEFAULT_LIMIT }), props.initialQuery));
    const [search, setSearch] = react_1.default.useState();
    const [searchValue] = (0, use_debounce_1.useDebounce)(search, 500);
    const fetchList = async () => {
        try {
            setIsLoading(true);
            const res = await props.httpRequest.get(`${props.endpoint}${(0, generateQueryString_1.generateQueryString)(query)}`);
            if (res && res.data && res.data.payload) {
                setPagination((oldVal) => {
                    return Object.assign(Object.assign({}, oldVal), { perPage: props.limit || DEFAULT_LIMIT, prev: res.data.payload.prev, next: res.data.payload.next, totalData: res.data.payload.count, countPage: Math.ceil(res.data.payload.count / (props.limit || DEFAULT_LIMIT)) });
                });
                if (props.pushData) {
                    let list = [...data, ...res.data.payload.results];
                    setData(list);
                }
                else {
                    setData(res.data.payload.results);
                }
                setIsLoading(false);
            }
            else {
                setIsLoading(false);
                antd_1.message.error('Failed to get data.');
            }
        }
        catch (error) {
            antd_1.message.error('Failed to get data. ' + (0, errorHandler_1.getErrorMessage)(error));
            setIsLoading(false);
        }
    };
    react_1.default.useEffect(() => {
        fetchList();
    }, [query]);
    react_1.default.useEffect(() => {
        setData([]);
        setQuery((e) => {
            return Object.assign(Object.assign({}, e), { search: searchValue });
        });
    }, [searchValue]);
    const changePage = (page) => {
        setPagination((oldVal) => {
            return Object.assign(Object.assign({}, oldVal), { page });
        });
        setQuery((oldVal) => {
            return Object.assign(Object.assign({}, oldVal), { offset: (page - 1) * (props.limit || DEFAULT_LIMIT) });
        });
    };
    const setQueryAndResetData = (newQuery) => {
        setData([]);
        setQuery((oldVal) => (Object.assign(Object.assign({}, oldVal), newQuery)));
    };
    return {
        isLoading,
        data,
        pagination,
        query,
        setData,
        setPagination,
        setQuery,
        setQueryAndResetData,
        setSearch,
        changePage,
        fetchList,
    };
}
exports.default = useFetchList;
